@@ -26,19 +26,16 @@
 
 #include "msettings.h"
 #include "mprocess.h"
-#include "partman.h"
 #include "swapman.h"
 #include "autopart.h"
 
 AutoPart::AutoPart(MProcess &mproc, PartMan *pman, Ui::MeInstall &ui, const class QSettings &appConf) noexcept
     : QObject(ui.boxSliderPart), proc(mproc), gui(ui), partman(pman)
 {
-    checkHibernation = gui.checkHibernationReg;
-
     connect(gui.comboDisk, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &AutoPart::diskChanged);
-    connect(gui.boxEncryptAuto, &QGroupBox::toggled, this, &AutoPart::toggleEncrypt);
+    connect(gui.checkEncryptAuto, &QCheckBox::toggled, this, &AutoPart::toggleEncrypt);
     connect(gui.checkHibernationReg, &QCheckBox::toggled, this,
-        [this](bool checked){ setParams(true, gui.boxEncryptAuto->isChecked(), checked, true); });
+        [this](bool checked){ setParams(true, gui.checkEncryptAuto->isChecked(), checked, true); });
     connect(gui.sliderPart, &QSlider::sliderPressed, this, &AutoPart::sliderPressed);
     connect(gui.sliderPart, &QSlider::actionTriggered, this, &AutoPart::sliderActionTriggered);
     connect(gui.sliderPart, &QSlider::valueChanged, this, &AutoPart::sliderValueChanged);
@@ -68,7 +65,7 @@ void AutoPart::manageConfig(MSettings &config) noexcept
 {
     config.startGroup("Storage", gui.pageDisk);
     config.manageComboBox("Drive", gui.comboDisk, true);
-    config.manageGroupCheckBox("DriveEncrypt", gui.boxEncryptAuto);
+    config.manageCheckBox("DriveEncrypt", gui.checkEncryptAuto);
     if (config.isSave()) {
         config.setValue("RootPortion", gui.sliderPart->value());
     } else if (config.contains("RootPortion")) {
@@ -86,11 +83,11 @@ void AutoPart::scan() noexcept
     long long minSpace = partman->volSpecTotal("/", QStringList()).minimum;
     gui.comboDisk->blockSignals(true);
     gui.comboDisk->clear();
-    for (DeviceItemIterator it(*partman); DeviceItem *item = *it; it.next()) {
-        if (item->type == DeviceItem::Drive && (!item->flags.bootRoot || installFromRootDevice)) {
-            drvitem = item;
+    for (PartMan::Iterator it(*partman); PartMan::Device *device = *it; it.next()) {
+        if (device->type == PartMan::Device::DRIVE && (!device->flags.bootRoot || installFromRootDevice)) {
+            drvitem = device;
             if (buildLayout(LLONG_MAX, false, false) >= minSpace) {
-                item->addToCombo(gui.comboDisk);
+                device->addToCombo(gui.comboDisk);
             }
         }
     }
@@ -127,7 +124,11 @@ void AutoPart::setParams(bool swapfile, bool encrypt, bool hibernation, bool sna
     const PartMan::VolumeSpec &vspecHome = partman->volSpecTotal("/home", volumes);
     minHome = vspecHome.minimum;
     recHome = vspecHome.preferred;
-    if (swapfile) recRoot += SwapMan::recommended(hibernation);
+    if (swapfile) {
+        const long long swapsize = SwapMan::recommended(hibernation);
+        recRoot += swapsize;
+        if (hibernation) minRoot += swapsize;
+    }
     if (snapshot) recHome += addSnapshot; // squashfs + ISO
 
     const int rootMinPercent = percent(minRoot, available, true);
@@ -159,7 +160,7 @@ long long AutoPart::partSize(Part part) const noexcept
 }
 
 // Layout Builder
-void AutoPart::builderGUI(DeviceItem *drive) noexcept
+void AutoPart::builderGUI(PartMan::Device *drive) noexcept
 {
     inBuilder = true;
     long long swapRec = SwapMan::recommended(false);
@@ -178,10 +179,10 @@ void AutoPart::builderGUI(DeviceItem *drive) noexcept
     const QLocale &syslocale = QLocale::system();
     QLabel *labelBase = new QLabel(syslocale.formattedDataSize(
         minRoot, 1, QLocale::DataSizeTraditionalFormat), &dialog);
-    QCheckBox *checkEncrypt = new QCheckBox(gui.boxEncryptAuto->title(), &dialog);
+    QCheckBox *checkEncrypt = new QCheckBox(gui.checkEncryptAuto->text(), &dialog);
     QCheckBox *checkSwapFile = new QCheckBox('+' + syslocale.formattedDataSize(
         swapRec, 1, QLocale::DataSizeTraditionalFormat), &dialog);
-    checkHibernation = new QCheckBox('+' + syslocale.formattedDataSize(
+    QCheckBox *checkHibernation = new QCheckBox('+' + syslocale.formattedDataSize(
         swapHiber-swapRec, 1, QLocale::DataSizeTraditionalFormat), &dialog);
     checkSnapshot = new QCheckBox('+' + syslocale.formattedDataSize(
         2*minRoot, 1, QLocale::DataSizeTraditionalFormat), &dialog);
@@ -234,7 +235,6 @@ void AutoPart::builderGUI(DeviceItem *drive) noexcept
 
     qApp->processEvents(); // Process residual signals.
     // Reset pointers to original controls.
-    checkHibernation = gui.checkHibernationReg;
     checkSnapshot = nullptr;
     inBuilder = false;
 }
@@ -251,14 +251,14 @@ long long AutoPart::buildLayout(long long rootFormatSize, bool crypto,
         if (updateTree) drvitem->addPart(256*MB, "ESP", crypto);
         if (volList) volList->append("ESP");
         remaining -= 256*MB;
-    } else if (drvitem->willUseGPT()) {
+    } else if (drvitem->format == "GPT") {
         if (updateTree) drvitem->addPart(1*MB, "BIOS-GRUB", crypto);
         if (volList) volList->append("BIOS-GRUB");
         remaining -= 1*MB;
     }
     if (crypto) {
         const long long bootFormatSize = partman->volSpecs["/boot"].preferred;
-        if (updateTree) drvitem->addPart(bootFormatSize, "boot", crypto);
+        if (updateTree) drvitem->addPart(bootFormatSize, "/boot", crypto);
         if (volList) volList->append("/boot");
         remaining -= bootFormatSize;
     }
@@ -271,8 +271,8 @@ long long AutoPart::buildLayout(long long rootFormatSize, bool crypto,
         if (remaining > 0) volList->append("/home");
     }
     if (updateTree) {
-        drvitem->addPart(rootFormatSize, "root", crypto);
-        if (remaining > 0) drvitem->addPart(remaining, "home", crypto);
+        drvitem->addPart(rootFormatSize, "/", crypto);
+        if (remaining > 0) drvitem->addPart(remaining, "/home", crypto);
         drvitem->labelParts();
         drvitem->driveAutoSetActive();
     }
@@ -299,11 +299,11 @@ void AutoPart::diskChanged() noexcept
 
     // Is encryption possible?
     const bool canEncrypt = (buildLayout(-1, true, false) >= minRoot);
-    gui.boxEncryptAuto->setEnabled(canEncrypt);
-    if (!canEncrypt) gui.boxEncryptAuto->setChecked(false);
+    gui.checkEncryptAuto->setEnabled(canEncrypt);
+    if (!canEncrypt) gui.checkEncryptAuto->setChecked(false);
 
     // Refresh encrypt/hibernate capabilities and cascade to set parameters.
-    toggleEncrypt(gui.boxEncryptAuto->isChecked());
+    toggleEncrypt(gui.checkEncryptAuto->isChecked());
 }
 void AutoPart::toggleEncrypt(bool checked) noexcept
 {
@@ -313,7 +313,6 @@ void AutoPart::toggleEncrypt(bool checked) noexcept
     if (!canHibernate) gui.checkHibernationReg->setChecked(false);
 
     setParams(true, checked, gui.checkHibernationReg->isChecked(), true);
-    if (!inBuilder) gui.pushNext->setEnabled(!checked || gui.textCryptoPass->isValid());
 }
 
 void AutoPart::sliderPressed() noexcept
@@ -385,10 +384,6 @@ void AutoPart::sliderValueChanged(int value) noexcept
     // Unselect features that won't fit with the current configuration.
     const QStringList vols(sizeRoot < available ? "/home" : "/");
     const long long rmin = partman->volSpecTotal("/", vols).minimum;
-    if (checkHibernation->isChecked() && sizeRoot < (rmin + SwapMan::recommended(true))) {
-        checkHibernation->setChecked(false);
-        QApplication::beep();
-    }
     if (checkSnapshot && checkSnapshot->isChecked()) {
         bool ok = false;
         if (!newHome) ok = (sizeRoot >= (rmin + addSnapshot));
